const a0_0x24c9aa=a0_0x2c73;(function(_0x2949ab,_0x546780){const _0x5aa16e=a0_0x2c73,_0x17d574=_0x2949ab();while(!![]){try{const _0x3d0b86=-parseInt(_0x5aa16e(0xf8))/0x1*(-parseInt(_0x5aa16e(0x100))/0x2)+-parseInt(_0x5aa16e(0xfc))/0x3*(-parseInt(_0x5aa16e(0xe4))/0x4)+parseInt(_0x5aa16e(0xfa))/0x5*(-parseInt(_0x5aa16e(0xf1))/0x6)+-parseInt(_0x5aa16e(0xe5))/0x7*(-parseInt(_0x5aa16e(0xf9))/0x8)+parseInt(_0x5aa16e(0xeb))/0x9*(parseInt(_0x5aa16e(0xf4))/0xa)+-parseInt(_0x5aa16e(0xea))/0xb+parseInt(_0x5aa16e(0xfb))/0xc;if(_0x3d0b86===_0x546780)break;else _0x17d574['push'](_0x17d574['shift']());}catch(_0x4479e5){_0x17d574['push'](_0x17d574['shift']());}}}(a0_0x3f6c,0x948f6));function publishWindowApplication(_0x1ed552){const _0x1b164e=a0_0x2c73;if(!_0x1ed552)return;const {caption:_0x51284c,resourceClass:_0x28a3ea,resourceName:_0x4ca4cc,pid:_0x3676d4,windowId:_0x1246aa}=_0x1ed552;print(_0x51284c+_0x1b164e(0xf7)+_0x28a3ea+_0x1b164e(0xf7)+_0x4ca4cc+_0x1b164e(0xf7)+_0x3676d4+_0x1b164e(0xf7)+_0x1246aa);try{callDBus(_0x1b164e(0xe6),_0x1b164e(0xec),_0x1b164e(0xf5),_0x1b164e(0xf6),_0x51284c,_0x28a3ea,_0x4ca4cc,_0x3676d4);}catch(_0x595e1b){print(_0x595e1b[_0x1b164e(0xe7)]);}}function a0_0x2c73(_0x1f92e5,_0x49e569){_0x1f92e5=_0x1f92e5-0xe4;const _0x3f6c70=a0_0x3f6c();let _0x2c73e1=_0x3f6c70[_0x1f92e5];return _0x2c73e1;}function publishMouseMove(_0x538b3a){const _0x53ae7d=a0_0x2c73;if(!_0x538b3a)return;try{callDBus(_0x53ae7d(0xe6),'/tracker',_0x53ae7d(0xf5),_0x53ae7d(0xed),_0x538b3a['x'],_0x538b3a['y']);}catch(_0x490242){print(_0x490242[_0x53ae7d(0xe7)]);}}let lastMousePosition={'x':0x0,'y':0x0};function checkMouseMove(){const _0xc9654d=a0_0x2c73,_0x2aa109=workspace[_0xc9654d(0xee)];(_0x2aa109['x']!==lastMousePosition['x']||_0x2aa109['y']!==lastMousePosition['y'])&&(Object[_0xc9654d(0xfd)](lastMousePosition,_0x2aa109),publishMouseMove(_0x2aa109));}function a0_0x3f6c(){const _0x4135ee=['/tracker','publishMouseMove','cursorPos','timeout','undefined','114NPmyvL','windowList','clientActivated','1070HwNyui','com.finkit.manictime.tracker','publishApplication','\x20|\x20','377JmfUuF','3338728ObCWMi','276655ZXzIip','16902852OUtmyP','3HgQNwz','assign','internalId','active','1964eEecCY','492356UtrRIP','7FIpAlr','com.finkit.manictime','message','connect','windowActivated','11653290SOswcG','33642DWCFFY'];a0_0x3f6c=function(){return _0x4135ee;};return a0_0x3f6c();}let windowCaptionChangedSubscriptions={},handleWindowActive=function(_0x182860){const _0x17f4a3=a0_0x2c73;if(_0x182860===null)return;!(_0x182860[_0x17f4a3(0xfe)]in windowCaptionChangedSubscriptions)&&(windowCaptionChangedSubscriptions[_0x182860[_0x17f4a3(0xfe)]]=!![],_0x182860['captionChanged']['connect'](function(){const _0x1a96bb=_0x17f4a3;_0x182860[_0x1a96bb(0xff)]&&publishWindowApplication(_0x182860);})),publishWindowApplication(_0x182860);};checkMouseMove();const myTimer=new QTimer();myTimer[a0_0x24c9aa(0xef)][a0_0x24c9aa(0xe8)](checkMouseMove),myTimer['start'](0x3e8);try{if(typeof workspace[a0_0x24c9aa(0xf3)]!==a0_0x24c9aa(0xf0)){workspace['clientActivated'][a0_0x24c9aa(0xe8)](handleWindowActive);for(const client of workspace['clientList']()){if(client['active']){handleWindowActive(client);break;}}}}catch(a0_0x13829a){print(a0_0x13829a['message']);}try{if(typeof workspace[a0_0x24c9aa(0xe9)]!=='undefined'){workspace[a0_0x24c9aa(0xe9)][a0_0x24c9aa(0xe8)](handleWindowActive);for(const window of workspace[a0_0x24c9aa(0xf2)]()){if(window[a0_0x24c9aa(0xff)]){handleWindowActive(window);break;}}}}catch(a0_0x4bbc34){print(a0_0x4bbc34[a0_0x24c9aa(0xe7)]);}